InheritedSVG

Struct InheritedSVG 

pub struct InheritedSVG {
    pub fill: T,
    pub fill_opacity: T,
    pub fill_rule: T,
    pub stroke: T,
    pub stroke_dasharray: T,
    pub stroke_dashoffset: T,
    pub stroke_miterlimit: T,
    pub stroke_opacity: T,
    pub stroke_width: T,
    pub stroke_linecap: T,
    pub stroke_linejoin: T,
}
The InheritedSVG style struct.

Fields

fill: T

The fill computed value.

fill_opacity: T

The fill-opacity computed value.

fill_rule: T

The fill-rule computed value.

stroke: T

The stroke computed value.

stroke_dasharray: T

The stroke-dasharray computed value.

stroke_dashoffset: T

The stroke-dashoffset computed value.

stroke_miterlimit: T

The stroke-miterlimit computed value.

stroke_opacity: T

The stroke-opacity computed value.

stroke_width: T

The stroke-width computed value.

stroke_linecap: T

The stroke-linecap computed value.

stroke_linejoin: T

The stroke-linejoin computed value.

Implementations

Source

impl InheritedSVG

pub fn set_fill(&mut self, v: T)

Set fill.

pub fn copy_fill_from(&mut self, other: &Self)

Set fill from other struct.

pub fn reset_fill(&mut self, other: &Self)

Reset fill from the initial struct.

pub fn clone_fill(&self) -> T

Get the computed value for fill.

pub fn fill_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for fill.

pub fn set_fill_opacity(&mut self, v: T)

Set fill-opacity.

pub fn copy_fill_opacity_from(&mut self, other: &Self)

Set fill-opacity from other struct.

pub fn reset_fill_opacity(&mut self, other: &Self)

Reset fill-opacity from the initial struct.

pub fn clone_fill_opacity(&self) -> T

Get the computed value for fill-opacity.

pub fn fill_opacity_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for fill-opacity.

pub fn set_fill_rule(&mut self, v: T)

Set fill-rule.

pub fn copy_fill_rule_from(&mut self, other: &Self)

Set fill-rule from other struct.

pub fn reset_fill_rule(&mut self, other: &Self)

Reset fill-rule from the initial struct.

pub fn clone_fill_rule(&self) -> T

Get the computed value for fill-rule.

pub fn fill_rule_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for fill-rule.

pub fn set_stroke(&mut self, v: T)

Set stroke.

pub fn copy_stroke_from(&mut self, other: &Self)

Set stroke from other struct.

pub fn reset_stroke(&mut self, other: &Self)

Reset stroke from the initial struct.

pub fn clone_stroke(&self) -> T

Get the computed value for stroke.

pub fn stroke_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for stroke.

pub fn set_stroke_dasharray(&mut self, v: T)

Set stroke-dasharray.

pub fn copy_stroke_dasharray_from(&mut self, other: &Self)

Set stroke-dasharray from other struct.

pub fn reset_stroke_dasharray(&mut self, other: &Self)

Reset stroke-dasharray from the initial struct.

pub fn clone_stroke_dasharray(&self) -> T

Get the computed value for stroke-dasharray.

pub fn stroke_dasharray_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for stroke-dasharray.

pub fn set_stroke_dashoffset(&mut self, v: T)

Set stroke-dashoffset.

pub fn copy_stroke_dashoffset_from(&mut self, other: &Self)

Set stroke-dashoffset from other struct.

pub fn reset_stroke_dashoffset(&mut self, other: &Self)

Reset stroke-dashoffset from the initial struct.

pub fn clone_stroke_dashoffset(&self) -> T

Get the computed value for stroke-dashoffset.

pub fn stroke_dashoffset_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for stroke-dashoffset.

pub fn set_stroke_miterlimit(&mut self, v: T)

Set stroke-miterlimit.

pub fn copy_stroke_miterlimit_from(&mut self, other: &Self)

Set stroke-miterlimit from other struct.

pub fn reset_stroke_miterlimit(&mut self, other: &Self)

Reset stroke-miterlimit from the initial struct.

pub fn clone_stroke_miterlimit(&self) -> T

Get the computed value for stroke-miterlimit.

pub fn stroke_miterlimit_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for stroke-miterlimit.

pub fn set_stroke_opacity(&mut self, v: T)

Set stroke-opacity.

pub fn copy_stroke_opacity_from(&mut self, other: &Self)

Set stroke-opacity from other struct.

pub fn reset_stroke_opacity(&mut self, other: &Self)

Reset stroke-opacity from the initial struct.

pub fn clone_stroke_opacity(&self) -> T

Get the computed value for stroke-opacity.

pub fn stroke_opacity_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for stroke-opacity.

pub fn set_stroke_width(&mut self, v: T)

Set stroke-width.

pub fn copy_stroke_width_from(&mut self, other: &Self)

Set stroke-width from other struct.

pub fn reset_stroke_width(&mut self, other: &Self)

Reset stroke-width from the initial struct.

pub fn clone_stroke_width(&self) -> T

Get the computed value for stroke-width.

pub fn stroke_width_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for stroke-width.

pub fn set_stroke_linecap(&mut self, v: T)

Set stroke-linecap.

pub fn copy_stroke_linecap_from(&mut self, other: &Self)

Set stroke-linecap from other struct.

pub fn reset_stroke_linecap(&mut self, other: &Self)

Reset stroke-linecap from the initial struct.

pub fn clone_stroke_linecap(&self) -> T

Get the computed value for stroke-linecap.

pub fn stroke_linecap_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for stroke-linecap.

pub fn set_stroke_linejoin(&mut self, v: T)

Set stroke-linejoin.

pub fn copy_stroke_linejoin_from(&mut self, other: &Self)

Set stroke-linejoin from other struct.

pub fn reset_stroke_linejoin(&mut self, other: &Self)

Reset stroke-linejoin from the initial struct.

pub fn clone_stroke_linejoin(&self) -> T

Get the computed value for stroke-linejoin.

pub fn stroke_linejoin_equals(&self, other: &Self) -> bool

Whether self and other have the same computed value for stroke-linejoin.