pub struct InheritedTable {
pub border_spacing: T,
pub caption_side: T,
pub border_collapse: T,
pub empty_cells: T,
}Expand description
The InheritedTable style struct.
Fields
border_spacing: TThe border-spacing computed value.
caption_side: TThe caption-side computed value.
border_collapse: TThe border-collapse computed value.
empty_cells: TThe empty-cells computed value.
Implementations
Sourceimpl InheritedTable
impl InheritedTable
Sourcepub fn set_border_spacing(&mut self, v: T)
pub fn set_border_spacing(&mut self, v: T)
Set border-spacing.
Sourcepub fn copy_border_spacing_from(&mut self, other: &Self)
pub fn copy_border_spacing_from(&mut self, other: &Self)
Set border-spacing from other struct.
Sourcepub fn reset_border_spacing(&mut self, other: &Self)
pub fn reset_border_spacing(&mut self, other: &Self)
Reset border-spacing from the initial struct.
Sourcepub fn clone_border_spacing(&self) -> T
pub fn clone_border_spacing(&self) -> T
Get the computed value for border-spacing.
Sourcepub fn border_spacing_equals(&self, other: &Self) -> bool
pub fn border_spacing_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for border-spacing.
Sourcepub fn set_caption_side(&mut self, v: T)
pub fn set_caption_side(&mut self, v: T)
Set caption-side.
Sourcepub fn copy_caption_side_from(&mut self, other: &Self)
pub fn copy_caption_side_from(&mut self, other: &Self)
Set caption-side from other struct.
Sourcepub fn reset_caption_side(&mut self, other: &Self)
pub fn reset_caption_side(&mut self, other: &Self)
Reset caption-side from the initial struct.
Sourcepub fn clone_caption_side(&self) -> T
pub fn clone_caption_side(&self) -> T
Get the computed value for caption-side.
Sourcepub fn caption_side_equals(&self, other: &Self) -> bool
pub fn caption_side_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for caption-side.
Sourcepub fn set_border_collapse(&mut self, v: T)
pub fn set_border_collapse(&mut self, v: T)
Set border-collapse.
Sourcepub fn copy_border_collapse_from(&mut self, other: &Self)
pub fn copy_border_collapse_from(&mut self, other: &Self)
Set border-collapse from other struct.
Sourcepub fn reset_border_collapse(&mut self, other: &Self)
pub fn reset_border_collapse(&mut self, other: &Self)
Reset border-collapse from the initial struct.
Sourcepub fn clone_border_collapse(&self) -> T
pub fn clone_border_collapse(&self) -> T
Get the computed value for border-collapse.
Sourcepub fn border_collapse_equals(&self, other: &Self) -> bool
pub fn border_collapse_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for border-collapse.
Sourcepub fn set_empty_cells(&mut self, v: T)
pub fn set_empty_cells(&mut self, v: T)
Set empty-cells.
Sourcepub fn copy_empty_cells_from(&mut self, other: &Self)
pub fn copy_empty_cells_from(&mut self, other: &Self)
Set empty-cells from other struct.
Sourcepub fn reset_empty_cells(&mut self, other: &Self)
pub fn reset_empty_cells(&mut self, other: &Self)
Reset empty-cells from the initial struct.
Sourcepub fn clone_empty_cells(&self) -> T
pub fn clone_empty_cells(&self) -> T
Get the computed value for empty-cells.
Sourcepub fn empty_cells_equals(&self, other: &Self) -> bool
pub fn empty_cells_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for empty-cells.