pub struct SVG {
pub clip_path: T,
pub mask_image: T,
pub mask_position_x: T,
pub mask_position_y: T,
pub mask_repeat: T,
pub mask_size: T,
pub mask_type: T,
pub mask_mode: T,
pub mask_clip: T,
pub mask_origin: T,
pub mask_composite: T,
}Expand description
The SVG style struct.
Fields
clip_path: TThe clip-path computed value.
mask_image: TThe mask-image computed value.
mask_position_x: TThe mask-position-x computed value.
mask_position_y: TThe mask-position-y computed value.
mask_repeat: TThe mask-repeat computed value.
mask_size: TThe mask-size computed value.
mask_type: TThe mask-type computed value.
mask_mode: TThe mask-mode computed value.
mask_clip: TThe mask-clip computed value.
mask_origin: TThe mask-origin computed value.
mask_composite: TThe mask-composite computed value.
Implementations
Sourceimpl SVG
impl SVG
Sourcepub fn set_clip_path(&mut self, v: T)
pub fn set_clip_path(&mut self, v: T)
Set clip-path.
Sourcepub fn copy_clip_path_from(&mut self, other: &Self)
pub fn copy_clip_path_from(&mut self, other: &Self)
Set clip-path from other struct.
Sourcepub fn reset_clip_path(&mut self, other: &Self)
pub fn reset_clip_path(&mut self, other: &Self)
Reset clip-path from the initial struct.
Sourcepub fn clone_clip_path(&self) -> T
pub fn clone_clip_path(&self) -> T
Get the computed value for clip-path.
Sourcepub fn clip_path_equals(&self, other: &Self) -> bool
pub fn clip_path_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for clip-path.
Sourcepub fn set_mask_image(&mut self, v: T)
pub fn set_mask_image(&mut self, v: T)
Set mask-image.
Sourcepub fn copy_mask_image_from(&mut self, other: &Self)
pub fn copy_mask_image_from(&mut self, other: &Self)
Set mask-image from other struct.
Sourcepub fn reset_mask_image(&mut self, other: &Self)
pub fn reset_mask_image(&mut self, other: &Self)
Reset mask-image from the initial struct.
Sourcepub fn clone_mask_image(&self) -> T
pub fn clone_mask_image(&self) -> T
Get the computed value for mask-image.
Sourcepub fn mask_image_equals(&self, other: &Self) -> bool
pub fn mask_image_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-image.
Sourcepub fn set_mask_position_x(&mut self, v: T)
pub fn set_mask_position_x(&mut self, v: T)
Set mask-position-x.
Sourcepub fn copy_mask_position_x_from(&mut self, other: &Self)
pub fn copy_mask_position_x_from(&mut self, other: &Self)
Set mask-position-x from other struct.
Sourcepub fn reset_mask_position_x(&mut self, other: &Self)
pub fn reset_mask_position_x(&mut self, other: &Self)
Reset mask-position-x from the initial struct.
Sourcepub fn clone_mask_position_x(&self) -> T
pub fn clone_mask_position_x(&self) -> T
Get the computed value for mask-position-x.
Sourcepub fn mask_position_x_equals(&self, other: &Self) -> bool
pub fn mask_position_x_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-position-x.
Sourcepub fn set_mask_position_y(&mut self, v: T)
pub fn set_mask_position_y(&mut self, v: T)
Set mask-position-y.
Sourcepub fn copy_mask_position_y_from(&mut self, other: &Self)
pub fn copy_mask_position_y_from(&mut self, other: &Self)
Set mask-position-y from other struct.
Sourcepub fn reset_mask_position_y(&mut self, other: &Self)
pub fn reset_mask_position_y(&mut self, other: &Self)
Reset mask-position-y from the initial struct.
Sourcepub fn clone_mask_position_y(&self) -> T
pub fn clone_mask_position_y(&self) -> T
Get the computed value for mask-position-y.
Sourcepub fn mask_position_y_equals(&self, other: &Self) -> bool
pub fn mask_position_y_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-position-y.
Sourcepub fn set_mask_repeat(&mut self, v: T)
pub fn set_mask_repeat(&mut self, v: T)
Set mask-repeat.
Sourcepub fn copy_mask_repeat_from(&mut self, other: &Self)
pub fn copy_mask_repeat_from(&mut self, other: &Self)
Set mask-repeat from other struct.
Sourcepub fn reset_mask_repeat(&mut self, other: &Self)
pub fn reset_mask_repeat(&mut self, other: &Self)
Reset mask-repeat from the initial struct.
Sourcepub fn clone_mask_repeat(&self) -> T
pub fn clone_mask_repeat(&self) -> T
Get the computed value for mask-repeat.
Sourcepub fn mask_repeat_equals(&self, other: &Self) -> bool
pub fn mask_repeat_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-repeat.
Sourcepub fn set_mask_size(&mut self, v: T)
pub fn set_mask_size(&mut self, v: T)
Set mask-size.
Sourcepub fn copy_mask_size_from(&mut self, other: &Self)
pub fn copy_mask_size_from(&mut self, other: &Self)
Set mask-size from other struct.
Sourcepub fn reset_mask_size(&mut self, other: &Self)
pub fn reset_mask_size(&mut self, other: &Self)
Reset mask-size from the initial struct.
Sourcepub fn clone_mask_size(&self) -> T
pub fn clone_mask_size(&self) -> T
Get the computed value for mask-size.
Sourcepub fn mask_size_equals(&self, other: &Self) -> bool
pub fn mask_size_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-size.
Sourcepub fn set_mask_type(&mut self, v: T)
pub fn set_mask_type(&mut self, v: T)
Set mask-type.
Sourcepub fn copy_mask_type_from(&mut self, other: &Self)
pub fn copy_mask_type_from(&mut self, other: &Self)
Set mask-type from other struct.
Sourcepub fn reset_mask_type(&mut self, other: &Self)
pub fn reset_mask_type(&mut self, other: &Self)
Reset mask-type from the initial struct.
Sourcepub fn clone_mask_type(&self) -> T
pub fn clone_mask_type(&self) -> T
Get the computed value for mask-type.
Sourcepub fn mask_type_equals(&self, other: &Self) -> bool
pub fn mask_type_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-type.
Sourcepub fn set_mask_mode(&mut self, v: T)
pub fn set_mask_mode(&mut self, v: T)
Set mask-mode.
Sourcepub fn copy_mask_mode_from(&mut self, other: &Self)
pub fn copy_mask_mode_from(&mut self, other: &Self)
Set mask-mode from other struct.
Sourcepub fn reset_mask_mode(&mut self, other: &Self)
pub fn reset_mask_mode(&mut self, other: &Self)
Reset mask-mode from the initial struct.
Sourcepub fn clone_mask_mode(&self) -> T
pub fn clone_mask_mode(&self) -> T
Get the computed value for mask-mode.
Sourcepub fn mask_mode_equals(&self, other: &Self) -> bool
pub fn mask_mode_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-mode.
Sourcepub fn set_mask_clip(&mut self, v: T)
pub fn set_mask_clip(&mut self, v: T)
Set mask-clip.
Sourcepub fn copy_mask_clip_from(&mut self, other: &Self)
pub fn copy_mask_clip_from(&mut self, other: &Self)
Set mask-clip from other struct.
Sourcepub fn reset_mask_clip(&mut self, other: &Self)
pub fn reset_mask_clip(&mut self, other: &Self)
Reset mask-clip from the initial struct.
Sourcepub fn clone_mask_clip(&self) -> T
pub fn clone_mask_clip(&self) -> T
Get the computed value for mask-clip.
Sourcepub fn mask_clip_equals(&self, other: &Self) -> bool
pub fn mask_clip_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-clip.
Sourcepub fn set_mask_origin(&mut self, v: T)
pub fn set_mask_origin(&mut self, v: T)
Set mask-origin.
Sourcepub fn copy_mask_origin_from(&mut self, other: &Self)
pub fn copy_mask_origin_from(&mut self, other: &Self)
Set mask-origin from other struct.
Sourcepub fn reset_mask_origin(&mut self, other: &Self)
pub fn reset_mask_origin(&mut self, other: &Self)
Reset mask-origin from the initial struct.
Sourcepub fn clone_mask_origin(&self) -> T
pub fn clone_mask_origin(&self) -> T
Get the computed value for mask-origin.
Sourcepub fn mask_origin_equals(&self, other: &Self) -> bool
pub fn mask_origin_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-origin.
Sourcepub fn set_mask_composite(&mut self, v: T)
pub fn set_mask_composite(&mut self, v: T)
Set mask-composite.
Sourcepub fn copy_mask_composite_from(&mut self, other: &Self)
pub fn copy_mask_composite_from(&mut self, other: &Self)
Set mask-composite from other struct.
Sourcepub fn reset_mask_composite(&mut self, other: &Self)
pub fn reset_mask_composite(&mut self, other: &Self)
Reset mask-composite from the initial struct.
Sourcepub fn clone_mask_composite(&self) -> T
pub fn clone_mask_composite(&self) -> T
Get the computed value for mask-composite.
Sourcepub fn mask_composite_equals(&self, other: &Self) -> bool
pub fn mask_composite_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for mask-composite.