pub struct InheritedSVG {
pub fill: T,
pub fill_opacity: T,
pub fill_rule: T,
pub stroke: T,
pub stroke_dasharray: T,
pub stroke_dashoffset: T,
pub stroke_miterlimit: T,
pub stroke_opacity: T,
pub stroke_width: T,
pub stroke_linecap: T,
pub stroke_linejoin: T,
}Expand description
The InheritedSVG style struct.
Fields
fill: TThe fill computed value.
fill_opacity: TThe fill-opacity computed value.
fill_rule: TThe fill-rule computed value.
stroke: TThe stroke computed value.
stroke_dasharray: TThe stroke-dasharray computed value.
stroke_dashoffset: TThe stroke-dashoffset computed value.
stroke_miterlimit: TThe stroke-miterlimit computed value.
stroke_opacity: TThe stroke-opacity computed value.
stroke_width: TThe stroke-width computed value.
stroke_linecap: TThe stroke-linecap computed value.
stroke_linejoin: TThe stroke-linejoin computed value.
Implementations
Sourceimpl InheritedSVG
impl InheritedSVG
Sourcepub fn copy_fill_from(&mut self, other: &Self)
pub fn copy_fill_from(&mut self, other: &Self)
Set fill from other struct.
Sourcepub fn reset_fill(&mut self, other: &Self)
pub fn reset_fill(&mut self, other: &Self)
Reset fill from the initial struct.
Sourcepub fn clone_fill(&self) -> T
pub fn clone_fill(&self) -> T
Get the computed value for fill.
Sourcepub fn fill_equals(&self, other: &Self) -> bool
pub fn fill_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for fill.
Sourcepub fn set_fill_opacity(&mut self, v: T)
pub fn set_fill_opacity(&mut self, v: T)
Set fill-opacity.
Sourcepub fn copy_fill_opacity_from(&mut self, other: &Self)
pub fn copy_fill_opacity_from(&mut self, other: &Self)
Set fill-opacity from other struct.
Sourcepub fn reset_fill_opacity(&mut self, other: &Self)
pub fn reset_fill_opacity(&mut self, other: &Self)
Reset fill-opacity from the initial struct.
Sourcepub fn clone_fill_opacity(&self) -> T
pub fn clone_fill_opacity(&self) -> T
Get the computed value for fill-opacity.
Sourcepub fn fill_opacity_equals(&self, other: &Self) -> bool
pub fn fill_opacity_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for fill-opacity.
Sourcepub fn set_fill_rule(&mut self, v: T)
pub fn set_fill_rule(&mut self, v: T)
Set fill-rule.
Sourcepub fn copy_fill_rule_from(&mut self, other: &Self)
pub fn copy_fill_rule_from(&mut self, other: &Self)
Set fill-rule from other struct.
Sourcepub fn reset_fill_rule(&mut self, other: &Self)
pub fn reset_fill_rule(&mut self, other: &Self)
Reset fill-rule from the initial struct.
Sourcepub fn clone_fill_rule(&self) -> T
pub fn clone_fill_rule(&self) -> T
Get the computed value for fill-rule.
Sourcepub fn fill_rule_equals(&self, other: &Self) -> bool
pub fn fill_rule_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for fill-rule.
Sourcepub fn set_stroke(&mut self, v: T)
pub fn set_stroke(&mut self, v: T)
Set stroke.
Sourcepub fn copy_stroke_from(&mut self, other: &Self)
pub fn copy_stroke_from(&mut self, other: &Self)
Set stroke from other struct.
Sourcepub fn reset_stroke(&mut self, other: &Self)
pub fn reset_stroke(&mut self, other: &Self)
Reset stroke from the initial struct.
Sourcepub fn clone_stroke(&self) -> T
pub fn clone_stroke(&self) -> T
Get the computed value for stroke.
Sourcepub fn stroke_equals(&self, other: &Self) -> bool
pub fn stroke_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for stroke.
Sourcepub fn set_stroke_dasharray(&mut self, v: T)
pub fn set_stroke_dasharray(&mut self, v: T)
Set stroke-dasharray.
Sourcepub fn copy_stroke_dasharray_from(&mut self, other: &Self)
pub fn copy_stroke_dasharray_from(&mut self, other: &Self)
Set stroke-dasharray from other struct.
Sourcepub fn reset_stroke_dasharray(&mut self, other: &Self)
pub fn reset_stroke_dasharray(&mut self, other: &Self)
Reset stroke-dasharray from the initial struct.
Sourcepub fn clone_stroke_dasharray(&self) -> T
pub fn clone_stroke_dasharray(&self) -> T
Get the computed value for stroke-dasharray.
Sourcepub fn stroke_dasharray_equals(&self, other: &Self) -> bool
pub fn stroke_dasharray_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for stroke-dasharray.
Sourcepub fn set_stroke_dashoffset(&mut self, v: T)
pub fn set_stroke_dashoffset(&mut self, v: T)
Set stroke-dashoffset.
Sourcepub fn copy_stroke_dashoffset_from(&mut self, other: &Self)
pub fn copy_stroke_dashoffset_from(&mut self, other: &Self)
Set stroke-dashoffset from other struct.
Sourcepub fn reset_stroke_dashoffset(&mut self, other: &Self)
pub fn reset_stroke_dashoffset(&mut self, other: &Self)
Reset stroke-dashoffset from the initial struct.
Sourcepub fn clone_stroke_dashoffset(&self) -> T
pub fn clone_stroke_dashoffset(&self) -> T
Get the computed value for stroke-dashoffset.
Sourcepub fn stroke_dashoffset_equals(&self, other: &Self) -> bool
pub fn stroke_dashoffset_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for stroke-dashoffset.
Sourcepub fn set_stroke_miterlimit(&mut self, v: T)
pub fn set_stroke_miterlimit(&mut self, v: T)
Set stroke-miterlimit.
Sourcepub fn copy_stroke_miterlimit_from(&mut self, other: &Self)
pub fn copy_stroke_miterlimit_from(&mut self, other: &Self)
Set stroke-miterlimit from other struct.
Sourcepub fn reset_stroke_miterlimit(&mut self, other: &Self)
pub fn reset_stroke_miterlimit(&mut self, other: &Self)
Reset stroke-miterlimit from the initial struct.
Sourcepub fn clone_stroke_miterlimit(&self) -> T
pub fn clone_stroke_miterlimit(&self) -> T
Get the computed value for stroke-miterlimit.
Sourcepub fn stroke_miterlimit_equals(&self, other: &Self) -> bool
pub fn stroke_miterlimit_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for stroke-miterlimit.
Sourcepub fn set_stroke_opacity(&mut self, v: T)
pub fn set_stroke_opacity(&mut self, v: T)
Set stroke-opacity.
Sourcepub fn copy_stroke_opacity_from(&mut self, other: &Self)
pub fn copy_stroke_opacity_from(&mut self, other: &Self)
Set stroke-opacity from other struct.
Sourcepub fn reset_stroke_opacity(&mut self, other: &Self)
pub fn reset_stroke_opacity(&mut self, other: &Self)
Reset stroke-opacity from the initial struct.
Sourcepub fn clone_stroke_opacity(&self) -> T
pub fn clone_stroke_opacity(&self) -> T
Get the computed value for stroke-opacity.
Sourcepub fn stroke_opacity_equals(&self, other: &Self) -> bool
pub fn stroke_opacity_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for stroke-opacity.
Sourcepub fn set_stroke_width(&mut self, v: T)
pub fn set_stroke_width(&mut self, v: T)
Set stroke-width.
Sourcepub fn copy_stroke_width_from(&mut self, other: &Self)
pub fn copy_stroke_width_from(&mut self, other: &Self)
Set stroke-width from other struct.
Sourcepub fn reset_stroke_width(&mut self, other: &Self)
pub fn reset_stroke_width(&mut self, other: &Self)
Reset stroke-width from the initial struct.
Sourcepub fn clone_stroke_width(&self) -> T
pub fn clone_stroke_width(&self) -> T
Get the computed value for stroke-width.
Sourcepub fn stroke_width_equals(&self, other: &Self) -> bool
pub fn stroke_width_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for stroke-width.
Sourcepub fn set_stroke_linecap(&mut self, v: T)
pub fn set_stroke_linecap(&mut self, v: T)
Set stroke-linecap.
Sourcepub fn copy_stroke_linecap_from(&mut self, other: &Self)
pub fn copy_stroke_linecap_from(&mut self, other: &Self)
Set stroke-linecap from other struct.
Sourcepub fn reset_stroke_linecap(&mut self, other: &Self)
pub fn reset_stroke_linecap(&mut self, other: &Self)
Reset stroke-linecap from the initial struct.
Sourcepub fn clone_stroke_linecap(&self) -> T
pub fn clone_stroke_linecap(&self) -> T
Get the computed value for stroke-linecap.
Sourcepub fn stroke_linecap_equals(&self, other: &Self) -> bool
pub fn stroke_linecap_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for stroke-linecap.
Sourcepub fn set_stroke_linejoin(&mut self, v: T)
pub fn set_stroke_linejoin(&mut self, v: T)
Set stroke-linejoin.
Sourcepub fn copy_stroke_linejoin_from(&mut self, other: &Self)
pub fn copy_stroke_linejoin_from(&mut self, other: &Self)
Set stroke-linejoin from other struct.
Sourcepub fn reset_stroke_linejoin(&mut self, other: &Self)
pub fn reset_stroke_linejoin(&mut self, other: &Self)
Reset stroke-linejoin from the initial struct.
Sourcepub fn clone_stroke_linejoin(&self) -> T
pub fn clone_stroke_linejoin(&self) -> T
Get the computed value for stroke-linejoin.
Sourcepub fn stroke_linejoin_equals(&self, other: &Self) -> bool
pub fn stroke_linejoin_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for stroke-linejoin.